@@ -3,7 +3,7 @@ import subprocess
 import tempfile as tf
 from . import vars
 
-def remote_exec(path, rdir="", verbose=True, logfile=None):
+def remote_exec(path, rdir="./", verbose=True, logfile=None):
     # If localhost, return
     if 'localhost' in vars.ssh_host or '127.0.0.1' in vars.ssh_host:
         print("Running on local machine...")
@@ -12,7 +12,8 @@ def remote_exec(path, rdir="", verbose=True, logfile=None):
     # Open the calling script (from path) and read the file
     fin = open(path, 'r')
     # Split the script and take everything after separator
-    s = fin.read().split("remote_exec(__file__)")[-1]
+    s = fin.read().split("__file__")[-1]
+    s = s[s.find("\n")+1:len(s)]   
     # Do we need to import CloudComputing? 
     if "CloudComputing" in s or "cc" in s:
         s = "import CloudComputing as cc\n" + s
@@ -24,9 +25,10 @@ def remote_exec(path, rdir="", verbose=True, logfile=None):
     # CD to remote dir (if any)
     cmd = cmd = "/usr/bin/ssh -p {} {}".format(vars.ssh_port, vars.ssh_host)
     cmd = cmd + " 'cd {} &&".format(rdir)
+    # Copy the temp file (script) to the remote working dir
+    os.system("/usr/bin/scp -P {} {} {}:{}".format(vars.ssh_port, tmp, vars.ssh_host, rdir))
     # Run over SSH
-    print(vars.ssh_host + " " + vars.ssh_port)
-    cmd = cmd + " python -V && python -u -' < {}".format(tmp)
+    cmd = cmd + " python {}'".format(tmp.split("/")[-1]) # Remove "/tmp/" from the filename
     print(cmd)
     if not verbose:
         cmd = cmd + " 1>/dev/null 2>&1"
@@ -34,7 +36,9 @@ def remote_exec(path, rdir="", verbose=True, logfile=None):
         print("Logging to file: {}".format(logfile))
         cmd = cmd + " > {}".format(logfile)
     subprocess.Popen(cmd, shell=True)
-    # Remove the temp file
+    # Remove the local temp file
     os.system("rm {}".format(tmp))
+    # Remove the remote temp file
+    os.system("/usr/bin/ssh -p {} {} 'rm {}/{}'".format(vars.ssh_port, vars.ssh_host, rdir, tmp.split("/")[-1]))
     # Exit to prevent the calling script to run locally
     exit(0)
\ No newline at end of file
